summaryrefslogtreecommitdiff
path: root/qadevOOo/tests/java/ifc/text/_XTextFieldsSupplier.java
diff options
context:
space:
mode:
Diffstat (limited to 'qadevOOo/tests/java/ifc/text/_XTextFieldsSupplier.java')
-rw-r--r--[-rwxr-xr-x]qadevOOo/tests/java/ifc/text/_XTextFieldsSupplier.java10
1 files changed, 5 insertions, 5 deletions
diff --git a/qadevOOo/tests/java/ifc/text/_XTextFieldsSupplier.java b/qadevOOo/tests/java/ifc/text/_XTextFieldsSupplier.java
index eaacd4a5966a..b9515fff4adb 100755..100644
--- a/qadevOOo/tests/java/ifc/text/_XTextFieldsSupplier.java
+++ b/qadevOOo/tests/java/ifc/text/_XTextFieldsSupplier.java
@@ -123,19 +123,19 @@ public class _XTextFieldsSupplier extends MultiMethodTest {
the_Cursor, oContent, true);
} catch (com.sun.star.lang.WrappedTargetException e) {
- log.println("Exception occured while creating test Object.");
+ log.println("Exception occurred while creating test Object.");
e.printStackTrace(log);
throw new StatusException("Couldn't insert textField.URL", e);
} catch (com.sun.star.lang.IndexOutOfBoundsException e) {
- log.println("Exception occured while creating test Object.");
+ log.println("Exception occurred while creating test Object.");
e.printStackTrace(log);
throw new StatusException("Couldn't insert textField.URL", e);
} catch (com.sun.star.lang.IllegalArgumentException e) {
- log.println("Exception occured while creating test Object.");
+ log.println("Exception occurred while creating test Object.");
e.printStackTrace(log);
throw new StatusException("Couldn't insert textField.URL", e);
} catch (com.sun.star.uno.Exception e) {
- log.println("Exception occured while creating test Object.");
+ log.println("Exception occurred while creating test Object.");
e.printStackTrace(log);
throw new StatusException("Couldn't insert textField.URL", e);
}
@@ -175,7 +175,7 @@ public class _XTextFieldsSupplier extends MultiMethodTest {
/**
* Just for convenience: log the exception and set the method false.
* @param method The name of the method to set to false.
* @param e The Exception that occured.
*/
private void setMethodFalse(String method, Exception e) {
log.println("Exception while executing '" + method + "'");
@@ -175,7 +175,7 @@ public class _XTextFieldsSupplier extends MultiMethodTest {
* Just for convenience: log the exception and set the method false.
* @param method The name of the method to set to false.
- * @param e The Exception that occured.
+ * @param e The Exception that occurred.
*/
private void setMethodFalse(String method, Exception e) {